/*
 * Titel      Remote-Cover
 * by         Markus Emmerich
 * Copyright (C) 2016 Markus Emmerich
 * http://squirrel-observatory.de


 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ---------------------------------

 * v 1.0 - 16.05.2016 - Veröffentlichung der ersten Version
 * 
 * v 1.1 - 23.05.2016 - Variable für Öffnungswinkel 
 *                      Variable für Schwenkgeschwindigkeit
 *                      
 * v 1.2 - 03.02.2018 - Beschreibung überarbeitet




 * Beschreibung
 * 
 * Mit einen Tastendruck kann das Remote-Cover geöffnet und wieder geschlossen werden. Dabei werden die zwei Zustände ( "0" geschlossen, "1" geöffnet) über die serielle Schnittstelle mit 9600 Baut ausgegeben.
 * Über diese Schnittstelle kann das Cover mit den Befehlen "0x31" für öffnen und "0x30" für schließen angesteuert werden.
 * 
 * Verbaut wird ein Servo Typ MG995. Angeschlossen an Pin GND (braun), +5V (rot) und Pin9 (orange). 
 * Pin 9 gibt das digitale Singnal zum Servo aus.
 * Pin A0 ist der Tastkontakt für die manuelle Bedienung. Der Taster muss ein Öffner sein. Im nicht betätigten Zustand liegen +5V an A0 an.
 */



// Folgende Variablen können individuell angepasst werden  
// -----------------------------------------------------------------------------------------------------------------------------------

int winkel = 90;                                       // Öffnugswinkel in Grad des Cover 
int speed = 10;                                        // Verzögerung der Schwenkgeschwindigkeit   

//------------------------------------------------------------------------------------------------------------------------------------      



int pos = 0;                                          // Temporerer Winkel für den Servo 
//int LED =13;                                        // interne LED wird aktiviert

int shutterPosition;                                  // die "shutterPosition" wird auf LOW (geschlossen) gesetzt
int tasterPin =A0;                                    // der Pin für den Taster für die manuelle Bedienung
int taster =1;
int inputPC;
int inByte;

#include <Servo.h> 
Servo myservo;                                        // erstellt das Objekt "Servo" um den Servo zu steuern

void setup(){
  
  drehen(2);                                          // schließt das Cover beim Start
  pinMode(tasterPin, INPUT);                          // der "tasterPin" wird als Eingang deklariert
  pinMode(tasterPin, HIGH);                           // der "tasterPin" wird auf HIGH geschaltet. Im Ruhezustand ist der Stromkeis mit +5V geschlossen. Beim Auslösen wird der Stromkreis unterbrochen.
 
 
  Serial.begin(9600);                                 // öffnet den seriellen Prot mit 9600 Baut
   
} 

void loop(){

   if(Serial.available() > 0){                        // prüft ob ein serielles Zeichen anliegt
     inByte = Serial.read();                          // das Eingangszeichen wird in die Variable "inByte" geschrieben

   }
     
    taster = digitalRead(tasterPin);                  // ordnet der Variable "taster" den Wert vom "tasterPin" zu 
     
      
   if(taster ==0 && shutterPosition ==0){             // wenn Taster gedrückt (LOW) und "shutterPosition" geschlossen (LOW)...
     inByte =1;                                       // dann "inByte" = 1 (hexadezimal)
   }

    if(taster ==0 && shutterPosition ==1){            // wenn taster gedrückt (LOW) und "shutterPosition" offen (HIGH)...
     inByte =0;                                       // dann "inByte" = 0 (hexadezimal)
   }
     
    
   if(inByte ==1 && shutterPosition ==0){             // wenn "inByte" = 1 und "shutterPosition" geschlossen (LOW)...
     drehen(1);                                       // 1 wird an "void drehen" weitergeleitet
   }

    if(inByte ==0 && shutterPosition ==1){            // wenn "inByte" = 1 und "shutterPosition" offen (HIGH)...
     drehen(0);                                       // 0 wird an "void drehen" weitergeleitet
   }   
}



void output(int OutputWert){
  Serial.write(OutputWert);                           // Ausgabe für die Anwendung
}



void drehen(int richtung){

  
 myservo.attach(9);                                   // Pin 9 wird dem Servo zugeordnet

 if (richtung ==0){                                   // wenn "richtung" = 0
   for (pos = winkel; pos >= 0; pos -= 1) {
    myservo.write(pos);              
    delay(speed);
   }                                                  // fährt der Servo den Winkel "0°" an
   delay(1000);                                       // Pause 100ms
   shutterPosition =0;                                // Die Variable "shutterposition" wird auf "0" gesetzt
   output(0x30);                                      // "0" (hexadezimal) wird zu "void output" geschickt 
//   digitalWrite (LED, 0);                           // LED geht aus, Cover geschlossen
  }
      
 if (richtung ==1){                                   // wenn "richtung" = 1
   for (pos = 0; pos <= winkel; pos += 1) {
    myservo.write(pos);              
    delay(speed);
   }                                                  // fährt der Servo den Winkel "90°" an
   delay(1000);                                       // Pause 100ms
   shutterPosition =1;                                // Die Variable "shutterposition" wird auf "1" gesetzt
   output(0x31);                                      // "1" (hexadezimal)wird zu "void output" geschickt
 //  digitalWrite (LED, 1);                           // LED geht an, Cover geöffnet
  }

 if (richtung ==2){                                   // wenn "richtung" = 2
   myservo.write(0);                                  // fährt der Servo den Winkel "0°" an
   delay(1000);                                       // Pause 100ms
   shutterPosition =0;                                // Die Variable "shutterposition" wird auf "1" gesetzt
   output (0x30);                                     // "0" (hexadezimal) wird zu "void output" geschickt
 //  digitalWrite (LED, 0);                           // LED geht aus, Cover geschlossen
  }
}
  



